Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/mcp_atlassian/__init__.py | 46 | 26 | 0 | 43%
src/mcp_atlassian/config.py | 17 | 2 | 0 | 88%
src/mcp_atlassian/confluence.py | 121 | 28 | 0 | 77%
src/mcp_atlassian/document_types.py | 5 | 0 | 0 | 100%
src/mcp_atlassian/jira.py | 415 | 181 | 0 | 56%
src/mcp_atlassian/preprocessing.py | 105 | 29 | 0 | 72%
src/mcp_atlassian/server.py | 267 | 267 | 0 | 0%
Total | 976 | 533 | 0 | 45%

No items found using the specified filter.